@@ -75,7 +75,8 @@ class Namespace(SessionBound):
         :param description: The description of the Tag to be created
         :param indexed: Whether the Tag will be indexed
         """
-        return self.fluid.tags[self.path].post(name, description, indexed)
+        self.fluid.tags[self.path].post(name, description, indexed)
+        return Tag(path_child(self.path, name))
 
     def delete(self):
         """Delete this namespace
@@ -246,8 +247,11 @@ class Tag(SessionBound):
 
     description = property(_get_description, _set_description)
 
-
-
+    def delete(self):
+        """
+        Delete this tag
+        """
+        self.api.delete()
 
 class readonly_tag_value(object):
     """Descriptor to provide a tag value lookup on an object to simulate a
