@@ -76,6 +76,13 @@ class NamespaceTest(unittest.TestCase):
         self.assertTrue(isinstance(child, Tag))
         self.assertEquals(child.path, u'test/test')
 
+    def test_create_delete_child_tag(self):
+        n = Namespace(u'test')
+        tag_name = str(uuid.uuid4())
+        new_tag = n.create_tag(tag_name, 'a test', False)
+        self.assertTrue(isinstance(new_tag, Tag))
+        new_tag.delete()
+        self.assertTrue(tag_name not in n.tag_names)
 
 class ObjectTest(unittest.TestCase):
 
